==> mastapy-12.0.3.post3-py3-none-any.whl: mastapy/system_model/fe/_2361.py <==
﻿"""_2361.py

OptionsWhenExternalFEFileAlreadyExists
"""


from typing import List

from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.python_net import python_net_import

_OPTIONS_WHEN_EXTERNAL_FE_FILE_ALREADY_EXISTS = python_net_import('SMT.MastaAPI.SystemModel.FE', 'OptionsWhenExternalFEFileAlreadyExists')


__docformat__ = 'restructuredtext en'
__all__ = ('OptionsWhenExternalFEFileAlreadyExists',)


class OptionsWhenExternalFEFileAlreadyExists(_0.APIBase):
    """OptionsWhenExternalFEFileAlreadyExists

    This is a mastapy class.
    """

    TYPE = _OPTIONS_WHEN_EXTERNAL_FE_FILE_ALREADY_EXISTS

    def __init__(self, instance_to_wrap: 'OptionsWhenExternalFEFileAlreadyExists.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def append_current_date_and_time_to_new_file_names(self) -> 'bool':
        """bool: 'AppendCurrentDateAndTimeToNewFileNames' is the original name of this property."""

        temp = self.wrapped.AppendCurrentDateAndTimeToNewFileNames

        if temp is None:
            return False

        return temp

    @append_current_date_and_time_to_new_file_names.setter
    def append_current_date_and_time_to_new_file_names(self, value: 'bool'):
        self.wrapped.AppendCurrentDateAndTimeToNewFileNames = bool(value) if value else False

    @property
    def output_mesh_file_path(self) -> 'str':
        """str: 'OutputMeshFilePath' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.OutputMeshFilePath

        if temp is None:
            return ''

        return temp

    @property
    def output_vectors_file_path(self) -> 'str':
        """str: 'OutputVectorsFilePath' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.OutputVectorsFilePath

        if temp is None:
            return ''

        return temp

    @property
    def overwrite_existing_mesh_file(self) -> 'bool':
        """bool: 'OverwriteExistingMeshFile' is the original name of this property."""

        temp = self.wrapped.OverwriteExistingMeshFile

        if temp is None:
            return False

        return temp

    @overwrite_existing_mesh_file.setter
    def overwrite_existing_mesh_file(self, value: 'bool'):
        self.wrapped.OverwriteExistingMeshFile = bool(value) if value else False

    @property
    def overwrite_existing_vectors_file(self) -> 'bool':
        """bool: 'OverwriteExistingVectorsFile' is the original name of this property."""

        temp = self.wrapped.OverwriteExistingVectorsFile

        if temp is None:
            return False

        return temp

    @overwrite_existing_vectors_file.setter
    def overwrite_existing_vectors_file(self, value: 'bool'):
        self.wrapped.OverwriteExistingVectorsFile = bool(value) if value else False

    @property
    def report_names(self) -> 'List[str]':
        """List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        """ 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else '')

    def get_default_report_with_encoded_images(self) -> 'str':
        """ 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        """ 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else '')

    def output_active_report_as_text_to(self, file_path: 'str'):
        """ 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else '')

    def get_active_report_with_encoded_images(self) -> 'str':
        """ 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else '', file_path if file_path else '')

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        """ 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        """

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else '')
        return method_result

==> mastapy-13.0.0a5-py3-none-any.whl: mastapy/system_model/fe/_2361.py <==
﻿"""_2361.py

FEExportSettings
"""
from __future__ import annotations

from typing import TYPE_CHECKING, List

from mastapy._internal import constructor, conversion
from mastapy import _0
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_FE_EXPORT_SETTINGS = python_net_import('SMT.MastaAPI.SystemModel.FE', 'FEExportSettings')


__docformat__ = 'restructuredtext en'
__all__ = ('FEExportSettings',)


class FEExportSettings(_0.APIBase):
    """FEExportSettings

    This is a mastapy class.
    """

    TYPE = _FE_EXPORT_SETTINGS

    class _Cast_FEExportSettings:
        """Special nested class for casting FEExportSettings to subclasses."""

        def __init__(self, parent: 'FEExportSettings'):
            self._parent = parent

        @property
        def fe_export_settings(self) -> 'FEExportSettings':
            return self._parent

        def __getattr__(self, name: str):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = ''.join(n.capitalize() for n in name.split('_'))
                raise CastException(f'Detected an invalid cast. Cannot cast to type "{class_name}"') from None

    def __init__(self, instance_to_wrap: 'FEExportSettings.TYPE'):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def report_names(self) -> 'List[str]':
        """List[str]: 'ReportNames' is the original name of this property.

        Note:
            This property is readonly.
        """

        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)
        return value

    def output_default_report_to(self, file_path: 'str'):
        """ 'OutputDefaultReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else '')

    def get_default_report_with_encoded_images(self) -> 'str':
        """ 'GetDefaultReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    def output_active_report_to(self, file_path: 'str'):
        """ 'OutputActiveReportTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else '')

    def output_active_report_as_text_to(self, file_path: 'str'):
        """ 'OutputActiveReportAsTextTo' is the original name of this method.

        Args:
            file_path (str)
        """

        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else '')

    def get_active_report_with_encoded_images(self) -> 'str':
        """ 'GetActiveReportWithEncodedImages' is the original name of this method.

        Returns:
            str
        """

        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    def output_named_report_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_masta_report(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsMastaReport' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(report_name if report_name else '', file_path if file_path else '')

    def output_named_report_as_text_to(self, report_name: 'str', file_path: 'str'):
        """ 'OutputNamedReportAsTextTo' is the original name of this method.

        Args:
            report_name (str)
            file_path (str)
        """

        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(report_name if report_name else '', file_path if file_path else '')

    def get_named_report_with_encoded_images(self, report_name: 'str') -> 'str':
        """ 'GetNamedReportWithEncodedImages' is the original name of this method.

        Args:
            report_name (str)

        Returns:
            str
        """

        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(report_name if report_name else '')
        return method_result

    @property
    def cast_to(self) -> 'FEExportSettings._Cast_FEExportSettings':
        return self._Cast_FEExportSettings(self)
